"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("./managers/modules-manager");
const app_1 = require("./app");
const logger_1 = require("./libs/logger");
const assert_1 = __importDefault(require("assert"));
const commander_1 = require("commander");
const package_json_1 = require("../package.json");
const root_scene_1 = require("./components/root-scene");
const packages_manager_1 = require("./managers/packages-manager");
commander_1.program
    .name(package_json_1.name)
    .aliases(Object.keys(package_json_1.bin).filter(e => e !== package_json_1.name))
    .description(package_json_1.description)
    .version(package_json_1.version, '-v, --version')
    .argument('<file>', 'scenario path or file')
    .argument('[password]', 'password to decrypt scene file')
    .enablePositionalOptions(true)
    .passThroughOptions(true)
    .showHelpAfterError(true)
    .option('--log <level>', 'set log details ("all", "trace", "debug", "info", "warn", "error", "fatal", "silent")')
    .option('-e, --env <key=value...>', 'environment variables')
    .action(async (source, password, opts = {}) => {
    try {
        await fetch('');
    }
    catch { }
    const { log, env } = opts;
    env?.filter((keyValue) => keyValue.includes('='))
        .forEach((keyValue) => {
        const idx = keyValue.indexOf('=');
        const key = keyValue.substring(0, idx);
        const vl = keyValue.substring(idx + 1);
        process.env[key] = vl;
    });
    if (log)
        logger_1.Logger.LogLevel = log;
    const appLogger = new logger_1.Logger(log ?? logger_1.LoggerLevel.INFO);
    const app = new app_1.App(appLogger, source, password);
    await app.exec();
})
    .addCommand(commander_1.program
    .createCommand('up')
    .aliases(['upgrade', 'update'])
    .description('upgrade external tags version')
    .argument('[package_name...]', 'packages in npm registry')
    .action(async (packagesNames) => {
    (0, assert_1.default)(packagesNames?.length, '"package(s)" is requried');
    const packages = packagesNames.map(extensionName => extensionName.includes('@') ? extensionName : `${extensionName}@latest`);
    const appLogger = new logger_1.Logger(logger_1.LoggerLevel.ALL);
    await new packages_manager_1.PackagesManager(new root_scene_1.RootScene({}, appLogger)).install(...packages);
}))
    .addHelpText('after', `More:
✔ Github project: ${package_json_1.homepage} 
✔ Npm package   : https://www.npmjs.com/package/${package_json_1.name}
✔ Docker Image  : https://hub.docker.com/repository/docker/doanthuanthanh88/${package_json_1.name}
`)
    .parse(process.argv);
//# sourceMappingURL=index.js.map